import React, { memo, useState, useEffect } from "react";
import { Platform } from "react-native";
import { parseUrlData, queryStringToJSON } from "./Forms/utils";
import {
  FORM_ALREADY_COMPLETED,
  FORM_ERROR,
  FORM_NOT_FOUND,
  predefineEmailAndName
} from "./Forms/helpers";
import { hasOpenedForm } from "./Forms/api/nativeforms-api";
import IFrameContainer from "./Forms/components/IFrameContainer";
import { LoadingError } from "./Forms/components/LoadingError";
import { PageLoader } from "./Forms/components/PageLoader";
import Forms from "./Forms";
import MobileContainer from "./Forms/components/MobileContainer";
const queryParams = queryStringToJSON();

const NativeForms = ({ form, onClose, onSend, email, name, customer }) => {
  const [formData, setFormData] = useState(null);
  const [error, setError] = useState(false);
  useEffect(() => {
    (async () => {
      if (!form) {
        setError("You forgot to provide form prop to NativeForms component");
        return;
      }

      const parameters = parseUrlData(form);

      if (parameters.l && parameters.f) {
        try {
          setFormData(null);
          const form = await hasOpenedForm(parameters);
          form.data.openedAt = new Date().toJSON();
          form.data.openedTimestamp = new Date().getTime();
          form.data.license = parameters.l;
          predefineEmailAndName(form.data, email, name, customer);
          setFormData(form.data);
        } catch (e) {
          setFormLoadingError(e);
        }
      } else {
        setFormLoadingError("Form does not exist or link is broken");
      }
    })();
  }, [customer, email, form, name]);

  const setFormLoadingError = e => {
    console.error(e);

    if (e.response && e.response.status === 409) {
      setError(FORM_ALREADY_COMPLETED);
    } else if (e.response && e.response.status === 404) {
      setError(FORM_NOT_FOUND);
    } else {
      setError(FORM_ERROR);
    }
  };

  if (Platform.OS !== "web") {
    return React.createElement(MobileContainer, {
      onSend: onSend,
      error: error,
      form: formData,
      onClose: onClose,
      livePreview: queryParams.livePreview
    });
  }

  if (queryParams.iframe) {
    return React.createElement(IFrameContainer, {
      onSend: onSend,
      onClose: onClose,
      error: error,
      form: formData,
      livePreview: queryParams.livePreview
    });
  }

  if (error)
    return React.createElement(LoadingError, {
      error: error
    });
  if (!formData) return React.createElement(PageLoader, null);
  return React.createElement(Forms, {
    livePreview: queryParams.livePreview,
    form: formData,
    onSend: onSend
  });
};

export default memo(NativeForms);
